@@ -237,3 +237,17 @@ class TestEncryptedTextFieldModel(TestCase):
             hmac_field__hash_of=expected,
         )
         self.assertEqual(updated_instance.first(), instance)
+
+    def test_pgp_public_key_negative_number(self):
+        """Assert negative value is saved with an `IntegerPGPPublicKeyField` field."""
+        expected = -1
+        instance = EncryptedTextFieldModelFactory.create(integer_pgp_pub_field=expected)
+
+        self.assertEqual(instance.integer_pgp_pub_field, expected)
+
+    def test_pgp_symmetric_key_negative_number(self):
+        """Assert negative value is saved with an `IntegerPGPSymmetricKeyField` field."""
+        expected = -1
+        instance = EncryptedTextFieldModelFactory.create(integer_pgp_sym_field=expected)
+
+        self.assertEqual(instance.integer_pgp_sym_field, expected)
